0 BOS/EOS,*,*,*,*,*,BOS/EOS
1 その他,間投,*,*,*,*,*
2 フィラー,*,*,*,*,*,*
3 感動詞,*,*,*,*,*,*
4 記号,アルファベット,*,*,*,*,*
5 記号,一般,*,*,*,*,*
6 記号,括弧開,*,*,*,*,BOS/EOS
7 記号,括弧閉,*,*,*,*,BOS/EOS
8 記号,句点,*,*,*,*,BOS/EOS
9 記号,空白,*,*,*,*,*
10 記号,読点,*,*,*,*,*
11 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,*
12 形容詞,自立,*,*,形容詞・アウオ段,ガル接続,無い
13 形容詞,自立,*,*,形容詞・アウオ段,仮定形,*
14 形容詞,自立,*,*,形容詞・アウオ段,仮定形,無い
15 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,*
16 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約１,無い
17 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,*
18 形容詞,自立,*,*,形容詞・アウオ段,仮定縮約２,無い
19 形容詞,自立,*,*,形容詞・アウオ段,基本形,*
20 形容詞,自立,*,*,形容詞・アウオ段,基本形,無い
21 形容詞,自立,*,*,形容詞・アウオ段,体言接続,*
22 形容詞,自立,*,*,形容詞・アウオ段,体言接続,無い
23 形容詞,自立,*,*,形容詞・アウオ段,文語基本形,*
24 形容詞,自立,*,*,形容詞・アウオ段,文語基本形,無い
25 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,*
26 形容詞,自立,*,*,形容詞・アウオ段,未然ウ接続,無い
27 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,*
28 形容詞,自立,*,*,形容詞・アウオ段,未然ヌ接続,無い
29 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,*
30 形容詞,自立,*,*,形容詞・アウオ段,命令ｅ,無い
31 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,*
32 形容詞,自立,*,*,形容詞・アウオ段,連用ゴザイ接続,無い
33 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,*
34 形容詞,自立,*,*,形容詞・アウオ段,連用タ接続,無い
35 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,*
36 形容詞,自立,*,*,形容詞・アウオ段,連用テ接続,無い
37 形容詞,自立,*,*,形容詞・イイ,基本形,無い
38 形容詞,自立,*,*,形容詞・イイ,基本形-促音便,無い
39 形容詞,自立,*,*,形容詞・イ段,ガル接続,*
40 形容詞,自立,*,*,形容詞・イ段,仮定形,*
41 形容詞,自立,*,*,形容詞・イ段,仮定縮約１,*
42 形容詞,自立,*,*,形容詞・イ段,仮定縮約２,*
43 形容詞,自立,*,*,形容詞・イ段,基本形,*
44 形容詞,自立,*,*,形容詞・イ段,体言接続,*
45 形容詞,自立,*,*,形容詞・イ段,文語基本形,*
46 形容詞,自立,*,*,形容詞・イ段,未然ウ接続,*
47 形容詞,自立,*,*,形容詞・イ段,未然ヌ接続,*
48 形容詞,自立,*,*,形容詞・イ段,命令ｅ,*
49 形容詞,自立,*,*,形容詞・イ段,連用ゴザイ接続,*
50 形容詞,自立,*,*,形容詞・イ段,連用タ接続,*
51 形容詞,自立,*,*,形容詞・イ段,連用テ接続,*
52 形容詞,自立,*,*,不変化型,基本形,*
53 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,*
54 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,たらしい
55 形容詞,接尾,*,*,形容詞・アウオ段,ガル接続,臭い
56 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,*
57 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,たらしい
58 形容詞,接尾,*,*,形容詞・アウオ段,仮定形,臭い
59 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,*
60 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,たらしい
61 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約１,臭い
62 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,*
63 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,たらしい
64 形容詞,接尾,*,*,形容詞・アウオ段,仮定縮約２,臭い
65 形容詞,接尾,*,*,形容詞・アウオ段,基本形,*
66 形容詞,接尾,*,*,形容詞・アウオ段,基本形,たらしい
67 形容詞,接尾,*,*,形容詞・アウオ段,基本形,臭い
68 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,*
69 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,たらしい
70 形容詞,接尾,*,*,形容詞・アウオ段,体言接続,臭い
71 形容詞,接尾,*,*,形容詞・アウオ段,文語基本形,*
72 形容詞,接尾,*,*,形容詞・アウオ段,文語基本形,たらしい
73 形容詞,接尾,*,*,形容詞・アウオ段,文語基本形,臭い
74 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,*
75 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,たらしい
76 形容詞,接尾,*,*,形容詞・アウオ段,未然ウ接続,臭い
77 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,*
78 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,たらしい
79 形容詞,接尾,*,*,形容詞・アウオ段,未然ヌ接続,臭い
80 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,*
81 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,たらしい
82 形容詞,接尾,*,*,形容詞・アウオ段,命令ｅ,臭い
83 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,*
84 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,たらしい
85 形容詞,接尾,*,*,形容詞・アウオ段,連用ゴザイ接続,臭い
86 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,*
87 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,たらしい
88 形容詞,接尾,*,*,形容詞・アウオ段,連用タ接続,臭い
89 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,*
90 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,たらしい
91 形容詞,接尾,*,*,形容詞・アウオ段,連用テ接続,臭い
92 形容詞,接尾,*,*,形容詞・イ段,ガル接続,たらしい
93 形容詞,接尾,*,*,形容詞・イ段,仮定形,たらしい
94 形容詞,接尾,*,*,形容詞・イ段,仮定縮約１,たらしい
95 形容詞,接尾,*,*,形容詞・イ段,仮定縮約２,たらしい
96 形容詞,接尾,*,*,形容詞・イ段,基本形,たらしい
97 形容詞,接尾,*,*,形容詞・イ段,体言接続,たらしい
98 形容詞,接尾,*,*,形容詞・イ段,文語基本形,たらしい
99 形容詞,接尾,*,*,形容詞・イ段,未然ウ接続,たらしい
100 形容詞,接尾,*,*,形容詞・イ段,未然ヌ接続,たらしい
101 形容詞,接尾,*,*,形容詞・イ段,命令ｅ,たらしい
102 形容詞,接尾,*,*,形容詞・イ段,連用ゴザイ接続,たらしい
103 形容詞,接尾,*,*,形容詞・イ段,連用タ接続,たらしい
104 形容詞,接尾,*,*,形容詞・イ段,連用テ接続,たらしい
105 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,難い
106 形容詞,非自立,*,*,形容詞・アウオ段,ガル接続,良い
107 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,難い
108 形容詞,非自立,*,*,形容詞・アウオ段,仮定形,良い
109 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,難い
110 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約１,良い
111 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,難い
112 形容詞,非自立,*,*,形容詞・アウオ段,仮定縮約２,良い
113 形容詞,非自立,*,*,形容詞・アウオ段,基本形,難い
114 形容詞,非自立,*,*,形容詞・アウオ段,基本形,良い
115 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,難い
116 形容詞,非自立,*,*,形容詞・アウオ段,体言接続,良い
117 形容詞,非自立,*,*,形容詞・アウオ段,文語基本形,難い
118 形容詞,非自立,*,*,形容詞・アウオ段,文語基本形,良い
119 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,難い
120 形容詞,非自立,*,*,形容詞・アウオ段,未然ウ接続,良い
121 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,難い
122 形容詞,非自立,*,*,形容詞・アウオ段,未然ヌ接続,良い
123 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,難い
124 形容詞,非自立,*,*,形容詞・アウオ段,命令ｅ,良い
125 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,難い
126 形容詞,非自立,*,*,形容詞・アウオ段,連用ゴザイ接続,良い
127 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,難い
128 形容詞,非自立,*,*,形容詞・アウオ段,連用タ接続,良い
129 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,難い
130 形容詞,非自立,*,*,形容詞・アウオ段,連用テ接続,良い
131 形容詞,非自立,*,*,形容詞・イイ,基本形,無い
132 形容詞,非自立,*,*,形容詞・イイ,基本形-促音便,無い
133 形容詞,非自立,*,*,形容詞・イ段,ガル接続,欲しい
134 形容詞,非自立,*,*,形容詞・イ段,仮定形,欲しい
135 形容詞,非自立,*,*,形容詞・イ段,仮定縮約１,欲しい
136 形容詞,非自立,*,*,形容詞・イ段,仮定縮約２,欲しい
137 形容詞,非自立,*,*,形容詞・イ段,基本形,欲しい
138 形容詞,非自立,*,*,形容詞・イ段,体言接続,欲しい
139 形容詞,非自立,*,*,形容詞・イ段,文語基本形,欲しい
140 形容詞,非自立,*,*,形容詞・イ段,未然ウ接続,欲しい
141 形容詞,非自立,*,*,形容詞・イ段,未然ヌ接続,欲しい
142 形容詞,非自立,*,*,形容詞・イ段,命令ｅ,欲しい
143 形容詞,非自立,*,*,形容詞・イ段,連用ゴザイ接続,欲しい
144 形容詞,非自立,*,*,形容詞・イ段,連用タ接続,欲しい
145 形容詞,非自立,*,*,形容詞・イ段,連用テ接続,欲しい
146 形容詞,非自立,*,*,不変化型,基本形,*
147 助詞,格助詞,一般,*,*,*,から
148 助詞,格助詞,一般,*,*,*,が
149 助詞,格助詞,一般,*,*,*,で
150 助詞,格助詞,一般,*,*,*,と
151 助詞,格助詞,一般,*,*,*,に
152 助詞,格助詞,一般,*,*,*,にて
153 助詞,格助詞,一般,*,*,*,の
154 助詞,格助詞,一般,*,*,*,へ
155 助詞,格助詞,一般,*,*,*,より
156 助詞,格助詞,一般,*,*,*,を
157 助詞,格助詞,一般,*,*,*,ん
158 助詞,格助詞,一般,*,*,*,デ
159 助詞,格助詞,一般,*,*,*,ノ
160 助詞,格助詞,一般,*,*,*,ヘ
161 助詞,格助詞,一般,*,*,*,ヲ
162 助詞,格助詞,一般,*,*,*,之
163 助詞,格助詞,引用,*,*,*,っと
164 助詞,格助詞,引用,*,*,*,と
165 助詞,格助詞,連語,*,*,*,じゃ
166 助詞,格助詞,連語,*,*,*,っちゅう
167 助詞,格助詞,連語,*,*,*,って
168 助詞,格助詞,連語,*,*,*,っていう
169 助詞,格助詞,連語,*,*,*,ってな
170 助詞,格助詞,連語,*,*,*,て
171 助詞,格助詞,連語,*,*,*,ていう
172 助詞,格助詞,連語,*,*,*,といいます
173 助詞,格助詞,連語,*,*,*,という
174 助詞,格助詞,連語,*,*,*,といった
175 助詞,格助詞,連語,*,*,*,といふ
176 助詞,格助詞,連語,*,*,*,とかいいます
177 助詞,格助詞,連語,*,*,*,とかいう
178 助詞,格助詞,連語,*,*,*,とかいふ
179 助詞,格助詞,連語,*,*,*,として
180 助詞,格助詞,連語,*,*,*,としましたら
181 助詞,格助詞,連語,*,*,*,としまして
182 助詞,格助詞,連語,*,*,*,とともに
183 助詞,格助詞,連語,*,*,*,と共に
184 助詞,格助詞,連語,*,*,*,にあたって
185 助詞,格助詞,連語,*,*,*,にあたり
186 助詞,格助詞,連語,*,*,*,にあたりまして
187 助詞,格助詞,連語,*,*,*,にあたります
188 助詞,格助詞,連語,*,*,*,にあたる
189 助詞,格助詞,連語,*,*,*,において
190 助詞,格助詞,連語,*,*,*,におきまして
191 助詞,格助詞,連語,*,*,*,における
192 助詞,格助詞,連語,*,*,*,にかけ
193 助詞,格助詞,連語,*,*,*,にかけて
194 助詞,格助詞,連語,*,*,*,にかけまして
195 助詞,格助詞,連語,*,*,*,にたいして
196 助詞,格助詞,連語,*,*,*,にたいしまして
197 助詞,格助詞,連語,*,*,*,にたいします
198 助詞,格助詞,連語,*,*,*,にたいする
199 助詞,格助詞,連語,*,*,*,について
200 助詞,格助詞,連語,*,*,*,につき
201 助詞,格助詞,連語,*,*,*,につきまして
202 助詞,格助詞,連語,*,*,*,につけ
203 助詞,格助詞,連語,*,*,*,につれ
204 助詞,格助詞,連語,*,*,*,につれて
205 助詞,格助詞,連語,*,*,*,にとって
206 助詞,格助詞,連語,*,*,*,にとり
207 助詞,格助詞,連語,*,*,*,にとりまして
208 助詞,格助詞,連語,*,*,*,にまつわります
209 助詞,格助詞,連語,*,*,*,にまつわる
210 助詞,格助詞,連語,*,*,*,によって
211 助詞,格助詞,連語,*,*,*,により
212 助詞,格助詞,連語,*,*,*,によりまして
213 助詞,格助詞,連語,*,*,*,によります
214 助詞,格助詞,連語,*,*,*,による
215 助詞,格助詞,連語,*,*,*,にわたって
216 助詞,格助詞,連語,*,*,*,にわたり
217 助詞,格助詞,連語,*,*,*,にわたりまして
218 助詞,格助詞,連語,*,*,*,にわたります
219 助詞,格助詞,連語,*,*,*,にわたる
220 助詞,格助詞,連語,*,*,*,に関し
221 助詞,格助詞,連語,*,*,*,に関して
222 助詞,格助詞,連語,*,*,*,に関しまして
223 助詞,格助詞,連語,*,*,*,に関します
224 助詞,格助詞,連語,*,*,*,に関する
225 助詞,格助詞,連語,*,*,*,に際し
226 助詞,格助詞,連語,*,*,*,に際して
227 助詞,格助詞,連語,*,*,*,に際しまして
228 助詞,格助詞,連語,*,*,*,に従い
229 助詞,格助詞,連語,*,*,*,に従いまして
230 助詞,格助詞,連語,*,*,*,に従います
231 助詞,格助詞,連語,*,*,*,に従う
232 助詞,格助詞,連語,*,*,*,に従って
233 助詞,格助詞,連語,*,*,*,に対し
234 助詞,格助詞,連語,*,*,*,に対して
235 助詞,格助詞,連語,*,*,*,に対しまして
236 助詞,格助詞,連語,*,*,*,に対します
237 助詞,格助詞,連語,*,*,*,に対する
238 助詞,格助詞,連語,*,*,*,に当たって
239 助詞,格助詞,連語,*,*,*,に当たり
240 助詞,格助詞,連語,*,*,*,に当たりまして
241 助詞,格助詞,連語,*,*,*,に当たります
242 助詞,格助詞,連語,*,*,*,に当たる
243 助詞,格助詞,連語,*,*,*,をめぐって
244 助詞,格助詞,連語,*,*,*,をめぐりまして
245 助詞,格助詞,連語,*,*,*,をめぐります
246 助詞,格助詞,連語,*,*,*,をめぐる
247 助詞,格助詞,連語,*,*,*,をもちまして
248 助詞,格助詞,連語,*,*,*,をもって
249 助詞,格助詞,連語,*,*,*,を以て
250 助詞,格助詞,連語,*,*,*,を通して
251 助詞,格助詞,連語,*,*,*,を通しまして
252 助詞,格助詞,連語,*,*,*,を通じ
253 助詞,格助詞,連語,*,*,*,を通じて
254 助詞,格助詞,連語,*,*,*,を通じまして
255 助詞,係助詞,*,*,*,*,こそ
256 助詞,係助詞,*,*,*,*,さえ
257 助詞,係助詞,*,*,*,*,しか
258 助詞,係助詞,*,*,*,*,すら
259 助詞,係助詞,*,*,*,*,ぞ
260 助詞,係助詞,*,*,*,*,っきゃ
261 助詞,係助詞,*,*,*,*,は
262 助詞,係助詞,*,*,*,*,も
263 助詞,係助詞,*,*,*,*,や
264 助詞,終助詞,*,*,*,*,かぁ
265 助詞,終助詞,*,*,*,*,かい
266 助詞,終助詞,*,*,*,*,かしら
267 助詞,終助詞,*,*,*,*,け
268 助詞,終助詞,*,*,*,*,さ
269 助詞,終助詞,*,*,*,*,ぜ
270 助詞,終助詞,*,*,*,*,ぞ
271 助詞,終助詞,*,*,*,*,だって
272 助詞,終助詞,*,*,*,*,っけ
273 助詞,終助詞,*,*,*,*,てん
274 助詞,終助詞,*,*,*,*,で
275 助詞,終助詞,*,*,*,*,な
276 助詞,終助詞,*,*,*,*,なー
277 助詞,終助詞,*,*,*,*,なぁー
278 助詞,終助詞,*,*,*,*,なァ
279 助詞,終助詞,*,*,*,*,ね
280 助詞,終助詞,*,*,*,*,ねー
281 助詞,終助詞,*,*,*,*,ねん
282 助詞,終助詞,*,*,*,*,の
283 助詞,終助詞,*,*,*,*,のう
284 助詞,終助詞,*,*,*,*,べ
285 助詞,終助詞,*,*,*,*,もん
286 助詞,終助詞,*,*,*,*,や
287 助詞,終助詞,*,*,*,*,やら
288 助詞,終助詞,*,*,*,*,よ
289 助詞,終助詞,*,*,*,*,よー
290 助詞,終助詞,*,*,*,*,よう
291 助詞,終助詞,*,*,*,*,わ
292 助詞,終助詞,*,*,*,*,わい
293 助詞,終助詞,*,*,*,*,ん
294 助詞,終助詞,*,*,*,*,ヨー
295 助詞,終助詞,*,*,*,*,ワ
296 助詞,接続助詞,*,*,*,*,および
297 助詞,接続助詞,*,*,*,*,から
298 助詞,接続助詞,*,*,*,*,からには
299 助詞,接続助詞,*,*,*,*,が
300 助詞,接続助詞,*,*,*,*,けども
301 助詞,接続助詞,*,*,*,*,けれど
302 助詞,接続助詞,*,*,*,*,けれども
303 助詞,接続助詞,*,*,*,*,さかい
304 助詞,接続助詞,*,*,*,*,し
305 助詞,接続助詞,*,*,*,*,たって
306 助詞,接続助詞,*,*,*,*,つつ
307 助詞,接続助詞,*,*,*,*,て
308 助詞,接続助詞,*,*,*,*,で
309 助詞,接続助詞,*,*,*,*,と
310 助詞,接続助詞,*,*,*,*,とも
311 助詞,接続助詞,*,*,*,*,ど
312 助詞,接続助詞,*,*,*,*,どころか
313 助詞,接続助詞,*,*,*,*,ども
314 助詞,接続助詞,*,*,*,*,ながら
315 助詞,接続助詞,*,*,*,*,なり
316 助詞,接続助詞,*,*,*,*,ので
317 助詞,接続助詞,*,*,*,*,のに
318 助詞,接続助詞,*,*,*,*,ば
319 助詞,接続助詞,*,*,*,*,ものの
320 助詞,接続助詞,*,*,*,*,や
321 助詞,接続助詞,*,*,*,*,やいなや
322 助詞,接続助詞,*,*,*,*,んで
323 助詞,特殊,*,*,*,*,かな
324 助詞,特殊,*,*,*,*,けむ
325 助詞,特殊,*,*,*,*,に
326 助詞,特殊,*,*,*,*,にゃ
327 助詞,特殊,*,*,*,*,ん
328 助詞,副詞化,*,*,*,*,と
329 助詞,副詞化,*,*,*,*,に
330 助詞,副助詞,*,*,*,*,かも
331 助詞,副助詞,*,*,*,*,くらい
332 助詞,副助詞,*,*,*,*,ぐらい
333 助詞,副助詞,*,*,*,*,しも
334 助詞,副助詞,*,*,*,*,じゃ
335 助詞,副助詞,*,*,*,*,じゃあ
336 助詞,副助詞,*,*,*,*,じゃァ
337 助詞,副助詞,*,*,*,*,ずつ
338 助詞,副助詞,*,*,*,*,だけ
339 助詞,副助詞,*,*,*,*,だって
340 助詞,副助詞,*,*,*,*,だに
341 助詞,副助詞,*,*,*,*,でも
342 助詞,副助詞,*,*,*,*,とも
343 助詞,副助詞,*,*,*,*,なぞ
344 助詞,副助詞,*,*,*,*,など
345 助詞,副助詞,*,*,*,*,なり
346 助詞,副助詞,*,*,*,*,なんか
347 助詞,副助詞,*,*,*,*,なんぞ
348 助詞,副助詞,*,*,*,*,なんて
349 助詞,副助詞,*,*,*,*,のみ
350 助詞,副助詞,*,*,*,*,ばかし
351 助詞,副助詞,*,*,*,*,ばかり
352 助詞,副助詞,*,*,*,*,ばっか
353 助詞,副助詞,*,*,*,*,ばっかり
354 助詞,副助詞,*,*,*,*,ほど
355 助詞,副助詞,*,*,*,*,まで
356 助詞,副助詞,*,*,*,*,やら
357 助詞,副助詞,*,*,*,*,程
358 助詞,副助詞,*,*,*,*,迄
359 助詞,副助詞／並立助詞／終助詞,*,*,*,*,か
360 助詞,並立助詞,*,*,*,*,たり
361 助詞,並立助詞,*,*,*,*,だの
362 助詞,並立助詞,*,*,*,*,だり
363 助詞,並立助詞,*,*,*,*,と
364 助詞,並立助詞,*,*,*,*,とか
365 助詞,並立助詞,*,*,*,*,なり
366 助詞,並立助詞,*,*,*,*,や
367 助詞,並立助詞,*,*,*,*,やら
368 助詞,連体化,*,*,*,*,の
369 助動詞,*,*,*,下二・タ行,仮定形,つ
370 助動詞,*,*,*,下二・タ行,基本形,つ
371 助動詞,*,*,*,下二・タ行,体言接続,つ
372 助動詞,*,*,*,下二・タ行,未然形,つ
373 助動詞,*,*,*,下二・タ行,命令ｙｏ,つ
374 助動詞,*,*,*,下二・タ行,連用形,つ
375 助動詞,*,*,*,形容詞・イ段,ガル接続,らしい
376 助動詞,*,*,*,形容詞・イ段,ガル接続,無い
377 助動詞,*,*,*,形容詞・イ段,仮定形,らしい
378 助動詞,*,*,*,形容詞・イ段,仮定形,無い
379 助動詞,*,*,*,形容詞・イ段,仮定縮約１,らしい
380 助動詞,*,*,*,形容詞・イ段,仮定縮約１,無い
381 助動詞,*,*,*,形容詞・イ段,仮定縮約２,らしい
382 助動詞,*,*,*,形容詞・イ段,仮定縮約２,無い
383 助動詞,*,*,*,形容詞・イ段,基本形,らしい
384 助動詞,*,*,*,形容詞・イ段,基本形,無い
385 助動詞,*,*,*,形容詞・イ段,体言接続,らしい
386 助動詞,*,*,*,形容詞・イ段,体言接続,無い
387 助動詞,*,*,*,形容詞・イ段,文語基本形,らしい
388 助動詞,*,*,*,形容詞・イ段,文語基本形,無い
389 助動詞,*,*,*,形容詞・イ段,未然ウ接続,らしい
390 助動詞,*,*,*,形容詞・イ段,未然ウ接続,無い
391 助動詞,*,*,*,形容詞・イ段,未然ヌ接続,らしい
392 助動詞,*,*,*,形容詞・イ段,未然ヌ接続,無い
393 助動詞,*,*,*,形容詞・イ段,命令ｅ,らしい
394 助動詞,*,*,*,形容詞・イ段,命令ｅ,無い
395 助動詞,*,*,*,形容詞・イ段,連用ゴザイ接続,らしい
396 助動詞,*,*,*,形容詞・イ段,連用ゴザイ接続,無い
397 助動詞,*,*,*,形容詞・イ段,連用タ接続,らしい
398 助動詞,*,*,*,形容詞・イ段,連用タ接続,無い
399 助動詞,*,*,*,形容詞・イ段,連用テ接続,らしい
400 助動詞,*,*,*,形容詞・イ段,連用テ接続,無い
401 助動詞,*,*,*,五段・ラ行アル,仮定形,ある
402 助動詞,*,*,*,五段・ラ行アル,仮定縮約１,ある
403 助動詞,*,*,*,五段・ラ行アル,基本形,ある
404 助動詞,*,*,*,五段・ラ行アル,体言接続特殊,ある
405 助動詞,*,*,*,五段・ラ行アル,未然ウ接続,ある
406 助動詞,*,*,*,五段・ラ行アル,未然形,ある
407 助動詞,*,*,*,五段・ラ行アル,命令ｅ,ある
408 助動詞,*,*,*,五段・ラ行アル,連用タ接続,ある
409 助動詞,*,*,*,五段・ラ行アル,連用形,ある
410 助動詞,*,*,*,五段・ラ行特殊,仮定形,ござる
411 助動詞,*,*,*,五段・ラ行特殊,仮定形,御座る
412 助動詞,*,*,*,五段・ラ行特殊,仮定縮約１,ござる
413 助動詞,*,*,*,五段・ラ行特殊,仮定縮約１,御座る
414 助動詞,*,*,*,五段・ラ行特殊,基本形,ござる
415 助動詞,*,*,*,五段・ラ行特殊,基本形,御座る
416 助動詞,*,*,*,五段・ラ行特殊,未然ウ接続,ござる
417 助動詞,*,*,*,五段・ラ行特殊,未然ウ接続,御座る
418 助動詞,*,*,*,五段・ラ行特殊,未然形,ござる
419 助動詞,*,*,*,五段・ラ行特殊,未然形,御座る
420 助動詞,*,*,*,五段・ラ行特殊,未然特殊,ござる
421 助動詞,*,*,*,五段・ラ行特殊,未然特殊,御座る
422 助動詞,*,*,*,五段・ラ行特殊,命令ｅ,ござる
423 助動詞,*,*,*,五段・ラ行特殊,命令ｅ,御座る
424 助動詞,*,*,*,五段・ラ行特殊,命令ｉ,ござる
425 助動詞,*,*,*,五段・ラ行特殊,命令ｉ,御座る
426 助動詞,*,*,*,五段・ラ行特殊,連用タ接続,ござる
427 助動詞,*,*,*,五段・ラ行特殊,連用タ接続,御座る
428 助動詞,*,*,*,五段・ラ行特殊,連用形,ござる
429 助動詞,*,*,*,五段・ラ行特殊,連用形,御座る
430 助動詞,*,*,*,特殊・ジャ,基本形,じゃ
431 助動詞,*,*,*,特殊・ジャ,未然形,じゃ
432 助動詞,*,*,*,特殊・ジャ,連用形,じゃ
433 助動詞,*,*,*,特殊・タ,仮定形,た
434 助動詞,*,*,*,特殊・タ,仮定形,だ
435 助動詞,*,*,*,特殊・タ,基本形,た
436 助動詞,*,*,*,特殊・タ,基本形,だ
437 助動詞,*,*,*,特殊・タ,未然形,た
438 助動詞,*,*,*,特殊・タ,未然形,だ
439 助動詞,*,*,*,特殊・タイ,ガル接続,たい
440 助動詞,*,*,*,特殊・タイ,音便基本形,たい
441 助動詞,*,*,*,特殊・タイ,仮定形,たい
442 助動詞,*,*,*,特殊・タイ,仮定縮約１,たい
443 助動詞,*,*,*,特殊・タイ,仮定縮約２,たい
444 助動詞,*,*,*,特殊・タイ,基本形,たい
445 助動詞,*,*,*,特殊・タイ,体言接続,たい
446 助動詞,*,*,*,特殊・タイ,文語基本形,たい
447 助動詞,*,*,*,特殊・タイ,未然ウ接続,たい
448 助動詞,*,*,*,特殊・タイ,未然ヌ接続,たい
449 助動詞,*,*,*,特殊・タイ,連用ゴザイ接続,たい
450 助動詞,*,*,*,特殊・タイ,連用タ接続,たい
451 助動詞,*,*,*,特殊・タイ,連用テ接続,たい
452 助動詞,*,*,*,特殊・ダ,仮定形,だ
453 助動詞,*,*,*,特殊・ダ,基本形,だ
454 助動詞,*,*,*,特殊・ダ,体言接続,だ
455 助動詞,*,*,*,特殊・ダ,未然形,だ
456 助動詞,*,*,*,特殊・ダ,命令ｅ,だ
457 助動詞,*,*,*,特殊・ダ,連用タ接続,だ
458 助動詞,*,*,*,特殊・ダ,連用形,だ
459 助動詞,*,*,*,特殊・デス,基本形,っす
460 助動詞,*,*,*,特殊・デス,基本形,です
461 助動詞,*,*,*,特殊・デス,基本形,どす
462 助動詞,*,*,*,特殊・デス,未然形,っす
463 助動詞,*,*,*,特殊・デス,未然形,です
464 助動詞,*,*,*,特殊・デス,未然形,どす
465 助動詞,*,*,*,特殊・デス,連用形,っす
466 助動詞,*,*,*,特殊・デス,連用形,です
467 助動詞,*,*,*,特殊・デス,連用形,どす
468 助動詞,*,*,*,特殊・ナイ,ガル接続,無い
469 助動詞,*,*,*,特殊・ナイ,音便基本形,無い
470 助動詞,*,*,*,特殊・ナイ,仮定形,無い
471 助動詞,*,*,*,特殊・ナイ,仮定縮約１,無い
472 助動詞,*,*,*,特殊・ナイ,仮定縮約２,無い
473 助動詞,*,*,*,特殊・ナイ,基本形,無い
474 助動詞,*,*,*,特殊・ナイ,体言接続,無い
475 助動詞,*,*,*,特殊・ナイ,文語基本形,無い
476 助動詞,*,*,*,特殊・ナイ,未然ウ接続,無い
477 助動詞,*,*,*,特殊・ナイ,未然ヌ接続,無い
478 助動詞,*,*,*,特殊・ナイ,命令ｅ,無い
479 助動詞,*,*,*,特殊・ナイ,連用ゴザイ接続,無い
480 助動詞,*,*,*,特殊・ナイ,連用タ接続,無い
481 助動詞,*,*,*,特殊・ナイ,連用テ接続,無い
482 助動詞,*,*,*,特殊・ナイ,連用デ接続,無い
483 助動詞,*,*,*,特殊・ヌ,仮定形,ぬ
484 助動詞,*,*,*,特殊・ヌ,基本形,ぬ
485 助動詞,*,*,*,特殊・ヌ,体言接続,ぬ
486 助動詞,*,*,*,特殊・ヌ,文語基本形,ぬ
487 助動詞,*,*,*,特殊・ヌ,連用ニ接続,ぬ
488 助動詞,*,*,*,特殊・ヌ,連用形,ぬ
489 助動詞,*,*,*,特殊・マス,仮定形,ます
490 助動詞,*,*,*,特殊・マス,仮定形,やす
491 助動詞,*,*,*,特殊・マス,基本形,ます
492 助動詞,*,*,*,特殊・マス,基本形,やす
493 助動詞,*,*,*,特殊・マス,未然ウ接続,ます
494 助動詞,*,*,*,特殊・マス,未然ウ接続,やす
495 助動詞,*,*,*,特殊・マス,未然形,ます
496 助動詞,*,*,*,特殊・マス,未然形,やす
497 助動詞,*,*,*,特殊・マス,命令ｅ,ます
498 助動詞,*,*,*,特殊・マス,命令ｅ,やす
499 助動詞,*,*,*,特殊・マス,命令ｉ,ます
500 助動詞,*,*,*,特殊・マス,命令ｉ,やす
501 助動詞,*,*,*,特殊・マス,連用形,ます
502 助動詞,*,*,*,特殊・マス,連用形,やす
503 助動詞,*,*,*,特殊・ヤ,基本形,や
504 助動詞,*,*,*,特殊・ヤ,未然形,や
505 助動詞,*,*,*,特殊・ヤ,連用形,や
506 助動詞,*,*,*,不変化型,基本形,う
507 助動詞,*,*,*,不変化型,基本形,じ
508 助動詞,*,*,*,不変化型,基本形,じゃん
509 助動詞,*,*,*,不変化型,基本形,じゃン
510 助動詞,*,*,*,不変化型,基本形,ぬ
511 助動詞,*,*,*,不変化型,基本形,ひん
512 助動詞,*,*,*,不変化型,基本形,へん
513 助動詞,*,*,*,不変化型,基本形,まい
514 助動詞,*,*,*,不変化型,基本形,やん
515 助動詞,*,*,*,不変化型,基本形,ん
516 助動詞,*,*,*,文語・キ,基本形,き
517 助動詞,*,*,*,文語・キ,体言接続,き
518 助動詞,*,*,*,文語・キ,命令ｅ,き
519 助動詞,*,*,*,文語・ケリ,基本形,けり
520 助動詞,*,*,*,文語・ケリ,体言接続,けり
521 助動詞,*,*,*,文語・ゴトシ,基本形,ごとし
522 助動詞,*,*,*,文語・ゴトシ,基本形,如し
523 助動詞,*,*,*,文語・ゴトシ,体言接続,ごとし
524 助動詞,*,*,*,文語・ゴトシ,体言接続,如し
525 助動詞,*,*,*,文語・ゴトシ,連用形,ごとし
526 助動詞,*,*,*,文語・ゴトシ,連用形,如し
527 助動詞,*,*,*,文語・ナリ,仮定形,たり
528 助動詞,*,*,*,文語・ナリ,仮定形,なり
529 助動詞,*,*,*,文語・ナリ,基本形,たり
530 助動詞,*,*,*,文語・ナリ,基本形,なり
531 助動詞,*,*,*,文語・ナリ,体言接続,たり
532 助動詞,*,*,*,文語・ナリ,体言接続,なり
533 助動詞,*,*,*,文語・ナリ,未然形,たり
534 助動詞,*,*,*,文語・ナリ,未然形,なり
535 助動詞,*,*,*,文語・ナリ,命令ｅ,たり
536 助動詞,*,*,*,文語・ナリ,命令ｅ,なり
537 助動詞,*,*,*,文語・ベシ,仮定形,べし
538 助動詞,*,*,*,文語・ベシ,基本形,べし
539 助動詞,*,*,*,文語・ベシ,体言接続,べし
540 助動詞,*,*,*,文語・ベシ,未然形,べし
541 助動詞,*,*,*,文語・ベシ,連用形,べし
542 助動詞,*,*,*,文語・マジ,仮定形,まじ
543 助動詞,*,*,*,文語・マジ,基本形,まじ
544 助動詞,*,*,*,文語・マジ,体言接続,まじ
545 助動詞,*,*,*,文語・マジ,連用形,まじ
546 助動詞,*,*,*,文語・リ,基本形,り
547 助動詞,*,*,*,文語・リ,体言接続,り
548 助動詞,*,*,*,文語・ル,仮定形,る
549 助動詞,*,*,*,文語・ル,基本形,る
550 助動詞,*,*,*,文語・ル,体言接続,る
551 助動詞,*,*,*,文語・ル,未然形,る
552 助動詞,*,*,*,文語・ル,命令ｅ,る
553 助動詞,*,*,*,文語・ル,命令ｙｏ,る
554 助動詞,*,*,*,文語・ル,連用形,る
555 接続詞,*,*,*,*,*,*
556 接続詞,*,*,*,*,*,および
557 接頭詞,形容詞接続,*,*,*,*,*
558 接頭詞,数接続,*,*,*,*,*
559 接頭詞,動詞接続,*,*,*,*,*
560 接頭詞,名詞接続,*,*,*,*,*
561 動詞,自立,*,*,カ変・クル,仮定形,*
562 動詞,自立,*,*,カ変・クル,仮定縮約１,*
563 動詞,自立,*,*,カ変・クル,基本形,*
564 動詞,自立,*,*,カ変・クル,体言接続特殊,*
565 動詞,自立,*,*,カ変・クル,体言接続特殊２,*
566 動詞,自立,*,*,カ変・クル,未然ウ接続,*
567 動詞,自立,*,*,カ変・クル,未然形,*
568 動詞,自立,*,*,カ変・クル,命令ｉ,*
569 動詞,自立,*,*,カ変・クル,命令ｙｏ,*
570 動詞,自立,*,*,カ変・クル,連用形,*
571 動詞,自立,*,*,カ変・来ル,仮定形,*
572 動詞,自立,*,*,カ変・来ル,仮定縮約１,*
573 動詞,自立,*,*,カ変・来ル,基本形,*
574 動詞,自立,*,*,カ変・来ル,体言接続特殊,*
575 動詞,自立,*,*,カ変・来ル,体言接続特殊２,*
576 動詞,自立,*,*,カ変・来ル,未然ウ接続,*
577 動詞,自立,*,*,カ変・来ル,未然形,*
578 動詞,自立,*,*,カ変・来ル,命令ｉ,*
579 動詞,自立,*,*,カ変・来ル,命令ｙｏ,*
580 動詞,自立,*,*,カ変・来ル,連用形,*
581 動詞,自立,*,*,サ変・−スル,仮定形,*
582 動詞,自立,*,*,サ変・−スル,仮定縮約１,*
583 動詞,自立,*,*,サ変・−スル,基本形,*
584 動詞,自立,*,*,サ変・−スル,文語基本形,*
585 動詞,自立,*,*,サ変・−スル,未然ウ接続,*
586 動詞,自立,*,*,サ変・−スル,未然レル接続,*
587 動詞,自立,*,*,サ変・−スル,未然形,*
588 動詞,自立,*,*,サ変・−スル,命令ｒｏ,*
589 動詞,自立,*,*,サ変・−スル,命令ｙｏ,*
590 動詞,自立,*,*,サ変・−ズル,仮定形,*
591 動詞,自立,*,*,サ変・−ズル,仮定縮約１,*
592 動詞,自立,*,*,サ変・−ズル,基本形,*
593 動詞,自立,*,*,サ変・−ズル,文語基本形,*
594 動詞,自立,*,*,サ変・−ズル,未然ウ接続,*
595 動詞,自立,*,*,サ変・−ズル,未然形,*
596 動詞,自立,*,*,サ変・−ズル,命令ｙｏ,*
597 動詞,自立,*,*,サ変・スル,仮定形,する
598 動詞,自立,*,*,サ変・スル,仮定縮約１,する
599 動詞,自立,*,*,サ変・スル,基本形,する
600 動詞,自立,*,*,サ変・スル,体言接続特殊,する
601 動詞,自立,*,*,サ変・スル,体言接続特殊２,する
602 動詞,自立,*,*,サ変・スル,文語基本形,する
603 動詞,自立,*,*,サ変・スル,未然ウ接続,する
604 動詞,自立,*,*,サ変・スル,未然ヌ接続,する
605 動詞,自立,*,*,サ変・スル,未然レル接続,する
606 動詞,自立,*,*,サ変・スル,未然形,する
607 動詞,自立,*,*,サ変・スル,命令ｉ,する
608 動詞,自立,*,*,サ変・スル,命令ｒｏ,する
609 動詞,自立,*,*,サ変・スル,命令ｙｏ,する
610 動詞,自立,*,*,サ変・スル,連用形,する
611 動詞,自立,*,*,ラ変,仮定形,*
612 動詞,自立,*,*,ラ変,基本形,*
613 動詞,自立,*,*,ラ変,体言接続,*
614 動詞,自立,*,*,ラ変,未然形,*
615 動詞,自立,*,*,ラ変,命令ｅ,*
616 動詞,自立,*,*,ラ変,連用形,*
617 動詞,自立,*,*,一段,仮定形,*
618 動詞,自立,*,*,一段,仮定縮約１,*
619 動詞,自立,*,*,一段,基本形,*
620 動詞,自立,*,*,一段,体言接続特殊,*
621 動詞,自立,*,*,一段,未然ウ接続,*
622 動詞,自立,*,*,一段,未然形,*
623 動詞,自立,*,*,一段,命令ｒｏ,*
624 動詞,自立,*,*,一段,命令ｙｏ,*
625 動詞,自立,*,*,一段,連用形,*
626 動詞,自立,*,*,一段・クレル,仮定形,*
627 動詞,自立,*,*,一段・クレル,仮定縮約１,*
628 動詞,自立,*,*,一段・クレル,基本形,*
629 動詞,自立,*,*,一段・クレル,未然ウ接続,*
630 動詞,自立,*,*,一段・クレル,未然形,*
631 動詞,自立,*,*,一段・クレル,未然特殊,*
632 動詞,自立,*,*,一段・クレル,命令ｅ,*
633 動詞,自立,*,*,一段・クレル,命令ｒｏ,*
634 動詞,自立,*,*,一段・クレル,命令ｙｏ,*
635 動詞,自立,*,*,一段・クレル,連用形,*
636 動詞,自立,*,*,一段・得ル,仮定形,*
637 動詞,自立,*,*,一段・得ル,基本形,*
638 動詞,自立,*,*,下二・カ行,仮定形,*
639 動詞,自立,*,*,下二・カ行,基本形,*
640 動詞,自立,*,*,下二・カ行,体言接続,*
641 動詞,自立,*,*,下二・カ行,未然形,*
642 動詞,自立,*,*,下二・カ行,命令ｙｏ,*
643 動詞,自立,*,*,下二・カ行,連用形,*
644 動詞,自立,*,*,下二・ガ行,仮定形,*
645 動詞,自立,*,*,下二・ガ行,基本形,*
646 動詞,自立,*,*,下二・ガ行,体言接続,*
647 動詞,自立,*,*,下二・ガ行,未然形,*
648 動詞,自立,*,*,下二・ガ行,命令ｙｏ,*
649 動詞,自立,*,*,下二・ガ行,連用形,*
650 動詞,自立,*,*,下二・ダ行,仮定形,*
651 動詞,自立,*,*,下二・ダ行,基本形,*
652 動詞,自立,*,*,下二・ダ行,体言接続,*
653 動詞,自立,*,*,下二・ダ行,未然形,*
654 動詞,自立,*,*,下二・ダ行,命令ｙｏ,*
655 動詞,自立,*,*,下二・ダ行,連用形,*
656 動詞,自立,*,*,下二・ハ行,仮定形,*
657 動詞,自立,*,*,下二・ハ行,基本形,*
658 動詞,自立,*,*,下二・ハ行,体言接続,*
659 動詞,自立,*,*,下二・ハ行,未然形,*
660 動詞,自立,*,*,下二・ハ行,命令ｙｏ,*
661 動詞,自立,*,*,下二・ハ行,連用形,*
662 動詞,自立,*,*,下二・マ行,仮定形,*
663 動詞,自立,*,*,下二・マ行,基本形,*
664 動詞,自立,*,*,下二・マ行,体言接続,*
665 動詞,自立,*,*,下二・マ行,未然形,*
666 動詞,自立,*,*,下二・マ行,命令ｙｏ,*
667 動詞,自立,*,*,下二・マ行,連用形,*
668 動詞,自立,*,*,下二・得,仮定形,*
669 動詞,自立,*,*,下二・得,基本形,*
670 動詞,自立,*,*,下二・得,体言接続,*
671 動詞,自立,*,*,下二・得,未然ウ接続,*
672 動詞,自立,*,*,下二・得,未然形,*
673 動詞,自立,*,*,下二・得,命令ｙｏ,*
674 動詞,自立,*,*,下二・得,連用形,*
675 動詞,自立,*,*,五段・カ行イ音便,仮定形,*
676 動詞,自立,*,*,五段・カ行イ音便,仮定形,行く
677 動詞,自立,*,*,五段・カ行イ音便,仮定縮約１,*
678 動詞,自立,*,*,五段・カ行イ音便,仮定縮約１,行く
679 動詞,自立,*,*,五段・カ行イ音便,基本形,*
680 動詞,自立,*,*,五段・カ行イ音便,基本形,行く
681 動詞,自立,*,*,五段・カ行イ音便,未然ウ接続,*
682 動詞,自立,*,*,五段・カ行イ音便,未然ウ接続,行く
683 動詞,自立,*,*,五段・カ行イ音便,未然形,*
684 動詞,自立,*,*,五段・カ行イ音便,未然形,行く
685 動詞,自立,*,*,五段・カ行イ音便,命令ｅ,*
686 動詞,自立,*,*,五段・カ行イ音便,命令ｅ,行く
687 動詞,自立,*,*,五段・カ行イ音便,連用タ接続,*
688 動詞,自立,*,*,五段・カ行イ音便,連用タ接続,行く
689 動詞,自立,*,*,五段・カ行イ音便,連用形,*
690 動詞,自立,*,*,五段・カ行イ音便,連用形,行く
691 動詞,自立,*,*,五段・カ行促音便,仮定形,*
692 動詞,自立,*,*,五段・カ行促音便,仮定形,行く
693 動詞,自立,*,*,五段・カ行促音便,仮定縮約１,*
694 動詞,自立,*,*,五段・カ行促音便,仮定縮約１,行く
695 動詞,自立,*,*,五段・カ行促音便,基本形,*
696 動詞,自立,*,*,五段・カ行促音便,基本形,行く
697 動詞,自立,*,*,五段・カ行促音便,未然ウ接続,*
698 動詞,自立,*,*,五段・カ行促音便,未然ウ接続,行く
699 動詞,自立,*,*,五段・カ行促音便,未然形,*
700 動詞,自立,*,*,五段・カ行促音便,未然形,行く
701 動詞,自立,*,*,五段・カ行促音便,命令ｅ,*
702 動詞,自立,*,*,五段・カ行促音便,命令ｅ,行く
703 動詞,自立,*,*,五段・カ行促音便,連用タ接続,*
704 動詞,自立,*,*,五段・カ行促音便,連用タ接続,行く
705 動詞,自立,*,*,五段・カ行促音便,連用形,*
706 動詞,自立,*,*,五段・カ行促音便,連用形,行く
707 動詞,自立,*,*,五段・カ行促音便ユク,仮定形,*
708 動詞,自立,*,*,五段・カ行促音便ユク,仮定形,行く
709 動詞,自立,*,*,五段・カ行促音便ユク,仮定縮約１,*
710 動詞,自立,*,*,五段・カ行促音便ユク,仮定縮約１,行く
711 動詞,自立,*,*,五段・カ行促音便ユク,基本形,*
712 動詞,自立,*,*,五段・カ行促音便ユク,基本形,行く
713 動詞,自立,*,*,五段・カ行促音便ユク,未然ウ接続,*
714 動詞,自立,*,*,五段・カ行促音便ユク,未然ウ接続,行く
715 動詞,自立,*,*,五段・カ行促音便ユク,未然形,*
716 動詞,自立,*,*,五段・カ行促音便ユク,未然形,行く
717 動詞,自立,*,*,五段・カ行促音便ユク,命令ｅ,*
718 動詞,自立,*,*,五段・カ行促音便ユク,命令ｅ,行く
719 動詞,自立,*,*,五段・カ行促音便ユク,連用形,*
720 動詞,自立,*,*,五段・カ行促音便ユク,連用形,行く
721 動詞,自立,*,*,五段・ガ行,仮定形,*
722 動詞,自立,*,*,五段・ガ行,仮定縮約１,*
723 動詞,自立,*,*,五段・ガ行,基本形,*
724 動詞,自立,*,*,五段・ガ行,未然ウ接続,*
725 動詞,自立,*,*,五段・ガ行,未然形,*
726 動詞,自立,*,*,五段・ガ行,命令ｅ,*
727 動詞,自立,*,*,五段・ガ行,連用タ接続,*
728 動詞,自立,*,*,五段・ガ行,連用形,*
729 動詞,自立,*,*,五段・サ行,仮定形,*
730 動詞,自立,*,*,五段・サ行,仮定縮約１,*
731 動詞,自立,*,*,五段・サ行,基本形,*
732 動詞,自立,*,*,五段・サ行,未然ウ接続,*
733 動詞,自立,*,*,五段・サ行,未然形,*
734 動詞,自立,*,*,五段・サ行,命令ｅ,*
735 動詞,自立,*,*,五段・サ行,連用形,*
736 動詞,自立,*,*,五段・タ行,仮定形,*
737 動詞,自立,*,*,五段・タ行,仮定縮約１,*
738 動詞,自立,*,*,五段・タ行,基本形,*
739 動詞,自立,*,*,五段・タ行,未然ウ接続,*
740 動詞,自立,*,*,五段・タ行,未然形,*
741 動詞,自立,*,*,五段・タ行,命令ｅ,*
742 動詞,自立,*,*,五段・タ行,連用タ接続,*
743 動詞,自立,*,*,五段・タ行,連用形,*
744 動詞,自立,*,*,五段・ナ行,仮定形,*
745 動詞,自立,*,*,五段・ナ行,仮定縮約１,*
746 動詞,自立,*,*,五段・ナ行,基本形,*
747 動詞,自立,*,*,五段・ナ行,未然ウ接続,*
748 動詞,自立,*,*,五段・ナ行,未然形,*
749 動詞,自立,*,*,五段・ナ行,命令ｅ,*
750 動詞,自立,*,*,五段・ナ行,連用タ接続,*
751 動詞,自立,*,*,五段・ナ行,連用形,*
752 動詞,自立,*,*,五段・バ行,仮定形,*
753 動詞,自立,*,*,五段・バ行,仮定縮約１,*
754 動詞,自立,*,*,五段・バ行,基本形,*
755 動詞,自立,*,*,五段・バ行,未然ウ接続,*
756 動詞,自立,*,*,五段・バ行,未然形,*
757 動詞,自立,*,*,五段・バ行,命令ｅ,*
758 動詞,自立,*,*,五段・バ行,連用タ接続,*
759 動詞,自立,*,*,五段・バ行,連用形,*
760 動詞,自立,*,*,五段・マ行,仮定形,*
761 動詞,自立,*,*,五段・マ行,仮定縮約１,*
762 動詞,自立,*,*,五段・マ行,基本形,*
763 動詞,自立,*,*,五段・マ行,未然ウ接続,*
764 動詞,自立,*,*,五段・マ行,未然形,*
765 動詞,自立,*,*,五段・マ行,命令ｅ,*
766 動詞,自立,*,*,五段・マ行,連用タ接続,*
767 動詞,自立,*,*,五段・マ行,連用形,*
768 動詞,自立,*,*,五段・ラ行,仮定形,*
769 動詞,自立,*,*,五段・ラ行,仮定形,する
770 動詞,自立,*,*,五段・ラ行,仮定縮約１,*
771 動詞,自立,*,*,五段・ラ行,仮定縮約１,する
772 動詞,自立,*,*,五段・ラ行,基本形,*
773 動詞,自立,*,*,五段・ラ行,基本形,する
774 動詞,自立,*,*,五段・ラ行,体言接続特殊,*
775 動詞,自立,*,*,五段・ラ行,体言接続特殊,する
776 動詞,自立,*,*,五段・ラ行,体言接続特殊２,*
777 動詞,自立,*,*,五段・ラ行,体言接続特殊２,する
778 動詞,自立,*,*,五段・ラ行,未然ウ接続,*
779 動詞,自立,*,*,五段・ラ行,未然ウ接続,する
780 動詞,自立,*,*,五段・ラ行,未然形,*
781 動詞,自立,*,*,五段・ラ行,未然形,する
782 動詞,自立,*,*,五段・ラ行,未然特殊,*
783 動詞,自立,*,*,五段・ラ行,未然特殊,する
784 動詞,自立,*,*,五段・ラ行,命令ｅ,*
785 動詞,自立,*,*,五段・ラ行,命令ｅ,する
786 動詞,自立,*,*,五段・ラ行,連用タ接続,*
787 動詞,自立,*,*,五段・ラ行,連用タ接続,する
788 動詞,自立,*,*,五段・ラ行,連用形,*
789 動詞,自立,*,*,五段・ラ行,連用形,する
790 動詞,自立,*,*,五段・ラ行特殊,仮定形,*
791 動詞,自立,*,*,五段・ラ行特殊,仮定縮約１,*
792 動詞,自立,*,*,五段・ラ行特殊,基本形,*
793 動詞,自立,*,*,五段・ラ行特殊,未然ウ接続,*
794 動詞,自立,*,*,五段・ラ行特殊,未然形,*
795 動詞,自立,*,*,五段・ラ行特殊,未然特殊,*
796 動詞,自立,*,*,五段・ラ行特殊,命令ｅ,*
797 動詞,自立,*,*,五段・ラ行特殊,命令ｉ,*
798 動詞,自立,*,*,五段・ラ行特殊,連用タ接続,*
799 動詞,自立,*,*,五段・ラ行特殊,連用形,*
800 動詞,自立,*,*,五段・ワ行ウ音便,仮定形,*
801 動詞,自立,*,*,五段・ワ行ウ音便,仮定形,言う
802 動詞,自立,*,*,五段・ワ行ウ音便,基本形,*
803 動詞,自立,*,*,五段・ワ行ウ音便,基本形,言う
804 動詞,自立,*,*,五段・ワ行ウ音便,未然ウ接続,*
805 動詞,自立,*,*,五段・ワ行ウ音便,未然ウ接続,言う
806 動詞,自立,*,*,五段・ワ行ウ音便,未然形,*
807 動詞,自立,*,*,五段・ワ行ウ音便,未然形,言う
808 動詞,自立,*,*,五段・ワ行ウ音便,命令ｅ,*
809 動詞,自立,*,*,五段・ワ行ウ音便,命令ｅ,言う
810 動詞,自立,*,*,五段・ワ行ウ音便,連用タ接続,*
811 動詞,自立,*,*,五段・ワ行ウ音便,連用タ接続,言う
812 動詞,自立,*,*,五段・ワ行ウ音便,連用形,*
813 動詞,自立,*,*,五段・ワ行ウ音便,連用形,言う
814 動詞,自立,*,*,五段・ワ行促音便,仮定形,*
815 動詞,自立,*,*,五段・ワ行促音便,仮定形,言う
816 動詞,自立,*,*,五段・ワ行促音便,仮定形,行う
817 動詞,自立,*,*,五段・ワ行促音便,基本形,*
818 動詞,自立,*,*,五段・ワ行促音便,基本形,言う
819 動詞,自立,*,*,五段・ワ行促音便,基本形,行う
820 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,*
821 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,言う
822 動詞,自立,*,*,五段・ワ行促音便,未然ウ接続,行う
823 動詞,自立,*,*,五段・ワ行促音便,未然形,*
824 動詞,自立,*,*,五段・ワ行促音便,未然形,言う
825 動詞,自立,*,*,五段・ワ行促音便,未然形,行う
826 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,*
827 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,言う
828 動詞,自立,*,*,五段・ワ行促音便,命令ｅ,行う
829 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,*
830 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,言う
831 動詞,自立,*,*,五段・ワ行促音便,連用タ接続,行う
832 動詞,自立,*,*,五段・ワ行促音便,連用形,*
833 動詞,自立,*,*,五段・ワ行促音便,連用形,言う
834 動詞,自立,*,*,五段・ワ行促音便,連用形,行う
835 動詞,自立,*,*,四段・サ行,仮定形,*
836 動詞,自立,*,*,四段・サ行,基本形,*
837 動詞,自立,*,*,四段・サ行,未然形,*
838 動詞,自立,*,*,四段・サ行,命令ｅ,*
839 動詞,自立,*,*,四段・サ行,連用形,*
840 動詞,自立,*,*,四段・タ行,仮定形,*
841 動詞,自立,*,*,四段・タ行,基本形,*
842 動詞,自立,*,*,四段・タ行,未然形,*
843 動詞,自立,*,*,四段・タ行,命令ｅ,*
844 動詞,自立,*,*,四段・タ行,連用形,*
845 動詞,自立,*,*,四段・ハ行,仮定形,*
846 動詞,自立,*,*,四段・ハ行,基本形,*
847 動詞,自立,*,*,四段・ハ行,未然形,*
848 動詞,自立,*,*,四段・ハ行,命令ｅ,*
849 動詞,自立,*,*,四段・ハ行,連用形,*
850 動詞,自立,*,*,四段・バ行,仮定形,*
851 動詞,自立,*,*,四段・バ行,基本形,*
852 動詞,自立,*,*,四段・バ行,未然形,*
853 動詞,自立,*,*,四段・バ行,命令ｅ,*
854 動詞,自立,*,*,四段・バ行,連用形,*
855 動詞,自立,*,*,上二・ダ行,仮定形,*
856 動詞,自立,*,*,上二・ダ行,基本形,*
857 動詞,自立,*,*,上二・ダ行,現代基本形,*
858 動詞,自立,*,*,上二・ダ行,体言接続,*
859 動詞,自立,*,*,上二・ダ行,未然形,*
860 動詞,自立,*,*,上二・ダ行,命令ｙｏ,*
861 動詞,自立,*,*,上二・ダ行,連用形,*
862 動詞,自立,*,*,上二・ハ行,仮定形,*
863 動詞,自立,*,*,上二・ハ行,基本形,*
864 動詞,自立,*,*,上二・ハ行,体言接続,*
865 動詞,自立,*,*,上二・ハ行,未然形,*
866 動詞,自立,*,*,上二・ハ行,命令ｙｏ,*
867 動詞,自立,*,*,上二・ハ行,連用形,*
868 動詞,接尾,*,*,一段,仮定形,*
869 動詞,接尾,*,*,一段,仮定縮約１,*
870 動詞,接尾,*,*,一段,基本形,*
871 動詞,接尾,*,*,一段,体言接続特殊,*
872 動詞,接尾,*,*,一段,未然ウ接続,*
873 動詞,接尾,*,*,一段,未然形,*
874 動詞,接尾,*,*,一段,命令ｒｏ,*
875 動詞,接尾,*,*,一段,命令ｙｏ,*
876 動詞,接尾,*,*,一段,連用形,*
877 動詞,接尾,*,*,五段・サ行,仮定形,*
878 動詞,接尾,*,*,五段・サ行,仮定縮約１,*
879 動詞,接尾,*,*,五段・サ行,基本形,*
880 動詞,接尾,*,*,五段・サ行,未然ウ接続,*
881 動詞,接尾,*,*,五段・サ行,未然形,*
882 動詞,接尾,*,*,五段・サ行,命令ｅ,*
883 動詞,接尾,*,*,五段・サ行,連用形,*
884 動詞,接尾,*,*,五段・ラ行,仮定形,*
885 動詞,接尾,*,*,五段・ラ行,仮定縮約１,*
886 動詞,接尾,*,*,五段・ラ行,基本形,*
887 動詞,接尾,*,*,五段・ラ行,体言接続特殊,*
888 動詞,接尾,*,*,五段・ラ行,体言接続特殊２,*
889 動詞,接尾,*,*,五段・ラ行,未然ウ接続,*
890 動詞,接尾,*,*,五段・ラ行,未然形,*
891 動詞,接尾,*,*,五段・ラ行,未然特殊,*
892 動詞,接尾,*,*,五段・ラ行,命令ｅ,*
893 動詞,接尾,*,*,五段・ラ行,連用タ接続,*
894 動詞,接尾,*,*,五段・ラ行,連用形,*
895 動詞,非自立,*,*,カ変・クル,仮定形,来る
896 動詞,非自立,*,*,カ変・クル,仮定縮約１,来る
897 動詞,非自立,*,*,カ変・クル,基本形,来る
898 動詞,非自立,*,*,カ変・クル,体言接続特殊,来る
899 動詞,非自立,*,*,カ変・クル,体言接続特殊２,来る
900 動詞,非自立,*,*,カ変・クル,未然ウ接続,来る
901 動詞,非自立,*,*,カ変・クル,未然形,来る
902 動詞,非自立,*,*,カ変・クル,命令ｉ,来る
903 動詞,非自立,*,*,カ変・クル,命令ｙｏ,来る
904 動詞,非自立,*,*,カ変・クル,連用形,来る
905 動詞,非自立,*,*,カ変・来ル,仮定形,来る
906 動詞,非自立,*,*,カ変・来ル,仮定縮約１,来る
907 動詞,非自立,*,*,カ変・来ル,基本形,来る
908 動詞,非自立,*,*,カ変・来ル,体言接続特殊,来る
909 動詞,非自立,*,*,カ変・来ル,体言接続特殊２,来る
910 動詞,非自立,*,*,カ変・来ル,未然ウ接続,来る
911 動詞,非自立,*,*,カ変・来ル,未然形,来る
912 動詞,非自立,*,*,カ変・来ル,命令ｉ,来る
913 動詞,非自立,*,*,カ変・来ル,命令ｙｏ,来る
914 動詞,非自立,*,*,カ変・来ル,連用形,来る
915 動詞,非自立,*,*,一段,仮定形,*
916 動詞,非自立,*,*,一段,仮定形,る
917 動詞,非自立,*,*,一段,仮定縮約１,*
918 動詞,非自立,*,*,一段,仮定縮約１,る
919 動詞,非自立,*,*,一段,基本形,*
920 動詞,非自立,*,*,一段,基本形,る
921 動詞,非自立,*,*,一段,体言接続特殊,*
922 動詞,非自立,*,*,一段,体言接続特殊,る
923 動詞,非自立,*,*,一段,未然ウ接続,*
924 動詞,非自立,*,*,一段,未然ウ接続,る
925 動詞,非自立,*,*,一段,未然形,*
926 動詞,非自立,*,*,一段,命令ｒｏ,*
927 動詞,非自立,*,*,一段,命令ｒｏ,る
928 動詞,非自立,*,*,一段,命令ｙｏ,*
929 動詞,非自立,*,*,一段,命令ｙｏ,る
930 動詞,非自立,*,*,一段,連用形,*
931 動詞,非自立,*,*,一段・クレル,仮定形,くれる
932 動詞,非自立,*,*,一段・クレル,仮定縮約１,くれる
933 動詞,非自立,*,*,一段・クレル,基本形,くれる
934 動詞,非自立,*,*,一段・クレル,未然ウ接続,くれる
935 動詞,非自立,*,*,一段・クレル,未然形,くれる
936 動詞,非自立,*,*,一段・クレル,未然特殊,くれる
937 動詞,非自立,*,*,一段・クレル,命令ｅ,くれる
938 動詞,非自立,*,*,一段・クレル,命令ｒｏ,くれる
939 動詞,非自立,*,*,一段・クレル,命令ｙｏ,くれる
940 動詞,非自立,*,*,一段・クレル,連用形,くれる
941 動詞,非自立,*,*,一段・得ル,仮定形,*
942 動詞,非自立,*,*,一段・得ル,基本形,*
943 動詞,非自立,*,*,五段・カ行イ音便,仮定形,*
944 動詞,非自立,*,*,五段・カ行イ音便,仮定形,おく
945 動詞,非自立,*,*,五段・カ行イ音便,仮定形,続く
946 動詞,非自立,*,*,五段・カ行イ音便,仮定形,頂く
947 動詞,非自立,*,*,五段・カ行イ音便,仮定形,抜く
948 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,*
949 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,おく
950 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,続く
951 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,頂く
952 動詞,非自立,*,*,五段・カ行イ音便,仮定縮約１,抜く
953 動詞,非自立,*,*,五段・カ行イ音便,基本形,*
954 動詞,非自立,*,*,五段・カ行イ音便,基本形,おく
955 動詞,非自立,*,*,五段・カ行イ音便,基本形,続く
956 動詞,非自立,*,*,五段・カ行イ音便,基本形,頂く
957 動詞,非自立,*,*,五段・カ行イ音便,基本形,抜く
958 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,*
959 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,おく
960 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,続く
961 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,頂く
962 動詞,非自立,*,*,五段・カ行イ音便,未然ウ接続,抜く
963 動詞,非自立,*,*,五段・カ行イ音便,未然形,*
964 動詞,非自立,*,*,五段・カ行イ音便,未然形,おく
965 動詞,非自立,*,*,五段・カ行イ音便,未然形,続く
966 動詞,非自立,*,*,五段・カ行イ音便,未然形,頂く
967 動詞,非自立,*,*,五段・カ行イ音便,未然形,抜く
968 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,*
969 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,おく
970 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,続く
971 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,頂く
972 動詞,非自立,*,*,五段・カ行イ音便,命令ｅ,抜く
973 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,*
974 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,おく
975 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,続く
976 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,頂く
977 動詞,非自立,*,*,五段・カ行イ音便,連用タ接続,抜く
978 動詞,非自立,*,*,五段・カ行イ音便,連用形,*
979 動詞,非自立,*,*,五段・カ行イ音便,連用形,おく
980 動詞,非自立,*,*,五段・カ行イ音便,連用形,続く
981 動詞,非自立,*,*,五段・カ行イ音便,連用形,頂く
982 動詞,非自立,*,*,五段・カ行イ音便,連用形,抜く
983 動詞,非自立,*,*,五段・カ行促音便,仮定形,*
984 動詞,非自立,*,*,五段・カ行促音便,仮定形,いく
985 動詞,非自立,*,*,五段・カ行促音便,仮定形,く
986 動詞,非自立,*,*,五段・カ行促音便,仮定形,行く
987 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,*
988 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,いく
989 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,く
990 動詞,非自立,*,*,五段・カ行促音便,仮定縮約１,行く
991 動詞,非自立,*,*,五段・カ行促音便,基本形,*
992 動詞,非自立,*,*,五段・カ行促音便,基本形,いく
993 動詞,非自立,*,*,五段・カ行促音便,基本形,く
994 動詞,非自立,*,*,五段・カ行促音便,基本形,行く
995 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,*
996 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,いく
997 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,く
998 動詞,非自立,*,*,五段・カ行促音便,未然ウ接続,行く
999 動詞,非自立,*,*,五段・カ行促音便,未然形,*
1000 動詞,非自立,*,*,五段・カ行促音便,未然形,いく
1001 動詞,非自立,*,*,五段・カ行促音便,未然形,く
1002 動詞,非自立,*,*,五段・カ行促音便,未然形,行く
1003 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,*
1004 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,いく
1005 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,く
1006 動詞,非自立,*,*,五段・カ行促音便,命令ｅ,行く
1007 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,*
1008 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,いく
1009 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,く
1010 動詞,非自立,*,*,五段・カ行促音便,連用タ接続,行く
1011 動詞,非自立,*,*,五段・カ行促音便,連用形,*
1012 動詞,非自立,*,*,五段・カ行促音便,連用形,いく
1013 動詞,非自立,*,*,五段・カ行促音便,連用形,く
1014 動詞,非自立,*,*,五段・カ行促音便,連用形,行く
1015 動詞,非自立,*,*,五段・カ行促音便ユク,仮定形,ゆく
1016 動詞,非自立,*,*,五段・カ行促音便ユク,仮定形,行く
1017 動詞,非自立,*,*,五段・カ行促音便ユク,仮定縮約１,ゆく
1018 動詞,非自立,*,*,五段・カ行促音便ユク,仮定縮約１,行く
1019 動詞,非自立,*,*,五段・カ行促音便ユク,基本形,ゆく
1020 動詞,非自立,*,*,五段・カ行促音便ユク,基本形,行く
1021 動詞,非自立,*,*,五段・カ行促音便ユク,未然ウ接続,ゆく
1022 動詞,非自立,*,*,五段・カ行促音便ユク,未然ウ接続,行く
1023 動詞,非自立,*,*,五段・カ行促音便ユク,未然形,ゆく
1024 動詞,非自立,*,*,五段・カ行促音便ユク,未然形,行く
1025 動詞,非自立,*,*,五段・カ行促音便ユク,命令ｅ,ゆく
1026 動詞,非自立,*,*,五段・カ行促音便ユク,命令ｅ,行く
1027 動詞,非自立,*,*,五段・カ行促音便ユク,連用形,ゆく
1028 動詞,非自立,*,*,五段・カ行促音便ユク,連用形,行く
1029 動詞,非自立,*,*,五段・サ行,仮定形,出す
1030 動詞,非自立,*,*,五段・サ行,仮定形,尽くす
1031 動詞,非自立,*,*,五段・サ行,仮定形,致す
1032 動詞,非自立,*,*,五段・サ行,仮定形,直す
1033 動詞,非自立,*,*,五段・サ行,仮定縮約１,出す
1034 動詞,非自立,*,*,五段・サ行,仮定縮約１,尽くす
1035 動詞,非自立,*,*,五段・サ行,仮定縮約１,致す
1036 動詞,非自立,*,*,五段・サ行,仮定縮約１,直す
1037 動詞,非自立,*,*,五段・サ行,基本形,出す
1038 動詞,非自立,*,*,五段・サ行,基本形,尽くす
1039 動詞,非自立,*,*,五段・サ行,基本形,致す
1040 動詞,非自立,*,*,五段・サ行,基本形,直す
1041 動詞,非自立,*,*,五段・サ行,未然ウ接続,出す
1042 動詞,非自立,*,*,五段・サ行,未然ウ接続,尽くす
1043 動詞,非自立,*,*,五段・サ行,未然ウ接続,致す
1044 動詞,非自立,*,*,五段・サ行,未然ウ接続,直す
1045 動詞,非自立,*,*,五段・サ行,未然形,出す
1046 動詞,非自立,*,*,五段・サ行,未然形,尽くす
1047 動詞,非自立,*,*,五段・サ行,未然形,致す
1048 動詞,非自立,*,*,五段・サ行,未然形,直す
1049 動詞,非自立,*,*,五段・サ行,命令ｅ,出す
1050 動詞,非自立,*,*,五段・サ行,命令ｅ,尽くす
1051 動詞,非自立,*,*,五段・サ行,命令ｅ,致す
1052 動詞,非自立,*,*,五段・サ行,命令ｅ,直す
1053 動詞,非自立,*,*,五段・サ行,連用形,出す
1054 動詞,非自立,*,*,五段・サ行,連用形,尽くす
1055 動詞,非自立,*,*,五段・サ行,連用形,致す
1056 動詞,非自立,*,*,五段・サ行,連用形,直す
1057 動詞,非自立,*,*,五段・マ行,仮定形,込む
1058 動詞,非自立,*,*,五段・マ行,仮定縮約１,込む
1059 動詞,非自立,*,*,五段・マ行,基本形,込む
1060 動詞,非自立,*,*,五段・マ行,未然ウ接続,込む
1061 動詞,非自立,*,*,五段・マ行,未然形,込む
1062 動詞,非自立,*,*,五段・マ行,命令ｅ,込む
1063 動詞,非自立,*,*,五段・マ行,連用タ接続,込む
1064 動詞,非自立,*,*,五段・マ行,連用形,込む
1065 動詞,非自立,*,*,五段・ラ行,仮定形,*
1066 動詞,非自立,*,*,五段・ラ行,仮定形,ある
1067 動詞,非自立,*,*,五段・ラ行,仮定形,おる
1068 動詞,非自立,*,*,五段・ラ行,仮定形,かかる
1069 動詞,非自立,*,*,五段・ラ行,仮定形,きる
1070 動詞,非自立,*,*,五段・ラ行,仮定形,なる
1071 動詞,非自立,*,*,五段・ラ行,仮定形,まいる
1072 動詞,非自立,*,*,五段・ラ行,仮定形,まわる
1073 動詞,非自立,*,*,五段・ラ行,仮定形,やる
1074 動詞,非自立,*,*,五段・ラ行,仮定形,回る
1075 動詞,非自立,*,*,五段・ラ行,仮定形,参る
1076 動詞,非自立,*,*,五段・ラ行,仮定形,終わる
1077 動詞,非自立,*,*,五段・ラ行,仮定形,切る
1078 動詞,非自立,*,*,五段・ラ行,仮定縮約１,*
1079 動詞,非自立,*,*,五段・ラ行,仮定縮約１,ある
1080 動詞,非自立,*,*,五段・ラ行,仮定縮約１,おる
1081 動詞,非自立,*,*,五段・ラ行,仮定縮約１,かかる
1082 動詞,非自立,*,*,五段・ラ行,仮定縮約１,きる
1083 動詞,非自立,*,*,五段・ラ行,仮定縮約１,なる
1084 動詞,非自立,*,*,五段・ラ行,仮定縮約１,まいる
1085 動詞,非自立,*,*,五段・ラ行,仮定縮約１,まわる
1086 動詞,非自立,*,*,五段・ラ行,仮定縮約１,やる
1087 動詞,非自立,*,*,五段・ラ行,仮定縮約１,回る
1088 動詞,非自立,*,*,五段・ラ行,仮定縮約１,参る
1089 動詞,非自立,*,*,五段・ラ行,仮定縮約１,終わる
1090 動詞,非自立,*,*,五段・ラ行,仮定縮約１,切る
1091 動詞,非自立,*,*,五段・ラ行,基本形,*
1092 動詞,非自立,*,*,五段・ラ行,基本形,ある
1093 動詞,非自立,*,*,五段・ラ行,基本形,おる
1094 動詞,非自立,*,*,五段・ラ行,基本形,かかる
1095 動詞,非自立,*,*,五段・ラ行,基本形,きる
1096 動詞,非自立,*,*,五段・ラ行,基本形,なる
1097 動詞,非自立,*,*,五段・ラ行,基本形,まいる
1098 動詞,非自立,*,*,五段・ラ行,基本形,まわる
1099 動詞,非自立,*,*,五段・ラ行,基本形,やる
1100 動詞,非自立,*,*,五段・ラ行,基本形,回る
1101 動詞,非自立,*,*,五段・ラ行,基本形,参る
1102 動詞,非自立,*,*,五段・ラ行,基本形,終わる
1103 動詞,非自立,*,*,五段・ラ行,基本形,切る
1104 動詞,非自立,*,*,五段・ラ行,体言接続特殊,*
1105 動詞,非自立,*,*,五段・ラ行,体言接続特殊,ある
1106 動詞,非自立,*,*,五段・ラ行,体言接続特殊,おる
1107 動詞,非自立,*,*,五段・ラ行,体言接続特殊,かかる
1108 動詞,非自立,*,*,五段・ラ行,体言接続特殊,きる
1109 動詞,非自立,*,*,五段・ラ行,体言接続特殊,なる
1110 動詞,非自立,*,*,五段・ラ行,体言接続特殊,まいる
1111 動詞,非自立,*,*,五段・ラ行,体言接続特殊,まわる
1112 動詞,非自立,*,*,五段・ラ行,体言接続特殊,やる
1113 動詞,非自立,*,*,五段・ラ行,体言接続特殊,回る
1114 動詞,非自立,*,*,五段・ラ行,体言接続特殊,参る
1115 動詞,非自立,*,*,五段・ラ行,体言接続特殊,終わる
1116 動詞,非自立,*,*,五段・ラ行,体言接続特殊,切る
1117 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,*
1118 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,ある
1119 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,おる
1120 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,かかる
1121 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,きる
1122 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,なる
1123 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,まいる
1124 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,まわる
1125 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,やる
1126 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,回る
1127 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,参る
1128 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,終わる
1129 動詞,非自立,*,*,五段・ラ行,体言接続特殊２,切る
1130 動詞,非自立,*,*,五段・ラ行,未然ウ接続,*
1131 動詞,非自立,*,*,五段・ラ行,未然ウ接続,ある
1132 動詞,非自立,*,*,五段・ラ行,未然ウ接続,おる
1133 動詞,非自立,*,*,五段・ラ行,未然ウ接続,かかる
1134 動詞,非自立,*,*,五段・ラ行,未然ウ接続,きる
1135 動詞,非自立,*,*,五段・ラ行,未然ウ接続,なる
1136 動詞,非自立,*,*,五段・ラ行,未然ウ接続,まいる
1137 動詞,非自立,*,*,五段・ラ行,未然ウ接続,まわる
1138 動詞,非自立,*,*,五段・ラ行,未然ウ接続,やる
1139 動詞,非自立,*,*,五段・ラ行,未然ウ接続,回る
1140 動詞,非自立,*,*,五段・ラ行,未然ウ接続,参る
1141 動詞,非自立,*,*,五段・ラ行,未然ウ接続,終わる
1142 動詞,非自立,*,*,五段・ラ行,未然ウ接続,切る
1143 動詞,非自立,*,*,五段・ラ行,未然形,*
1144 動詞,非自立,*,*,五段・ラ行,未然形,ある
1145 動詞,非自立,*,*,五段・ラ行,未然形,おる
1146 動詞,非自立,*,*,五段・ラ行,未然形,かかる
1147 動詞,非自立,*,*,五段・ラ行,未然形,きる
1148 動詞,非自立,*,*,五段・ラ行,未然形,なる
1149 動詞,非自立,*,*,五段・ラ行,未然形,まいる
1150 動詞,非自立,*,*,五段・ラ行,未然形,まわる
1151 動詞,非自立,*,*,五段・ラ行,未然形,やる
1152 動詞,非自立,*,*,五段・ラ行,未然形,回る
1153 動詞,非自立,*,*,五段・ラ行,未然形,参る
1154 動詞,非自立,*,*,五段・ラ行,未然形,終わる
1155 動詞,非自立,*,*,五段・ラ行,未然形,切る
1156 動詞,非自立,*,*,五段・ラ行,未然特殊,*
1157 動詞,非自立,*,*,五段・ラ行,未然特殊,ある
1158 動詞,非自立,*,*,五段・ラ行,未然特殊,おる
1159 動詞,非自立,*,*,五段・ラ行,未然特殊,かかる
1160 動詞,非自立,*,*,五段・ラ行,未然特殊,きる
1161 動詞,非自立,*,*,五段・ラ行,未然特殊,なる
1162 動詞,非自立,*,*,五段・ラ行,未然特殊,まいる
1163 動詞,非自立,*,*,五段・ラ行,未然特殊,まわる
1164 動詞,非自立,*,*,五段・ラ行,未然特殊,やる
1165 動詞,非自立,*,*,五段・ラ行,未然特殊,回る
1166 動詞,非自立,*,*,五段・ラ行,未然特殊,参る
1167 動詞,非自立,*,*,五段・ラ行,未然特殊,終わる
1168 動詞,非自立,*,*,五段・ラ行,未然特殊,切る
1169 動詞,非自立,*,*,五段・ラ行,命令ｅ,*
1170 動詞,非自立,*,*,五段・ラ行,命令ｅ,ある
1171 動詞,非自立,*,*,五段・ラ行,命令ｅ,おる
1172 動詞,非自立,*,*,五段・ラ行,命令ｅ,かかる
1173 動詞,非自立,*,*,五段・ラ行,命令ｅ,きる
1174 動詞,非自立,*,*,五段・ラ行,命令ｅ,なる
1175 動詞,非自立,*,*,五段・ラ行,命令ｅ,まいる
1176 動詞,非自立,*,*,五段・ラ行,命令ｅ,まわる
1177 動詞,非自立,*,*,五段・ラ行,命令ｅ,やる
1178 動詞,非自立,*,*,五段・ラ行,命令ｅ,回る
1179 動詞,非自立,*,*,五段・ラ行,命令ｅ,参る
1180 動詞,非自立,*,*,五段・ラ行,命令ｅ,終わる
1181 動詞,非自立,*,*,五段・ラ行,命令ｅ,切る
1182 動詞,非自立,*,*,五段・ラ行,連用タ接続,*
1183 動詞,非自立,*,*,五段・ラ行,連用タ接続,ある
1184 動詞,非自立,*,*,五段・ラ行,連用タ接続,おる
1185 動詞,非自立,*,*,五段・ラ行,連用タ接続,かかる
1186 動詞,非自立,*,*,五段・ラ行,連用タ接続,きる
1187 動詞,非自立,*,*,五段・ラ行,連用タ接続,なる
1188 動詞,非自立,*,*,五段・ラ行,連用タ接続,まいる
1189 動詞,非自立,*,*,五段・ラ行,連用タ接続,まわる
1190 動詞,非自立,*,*,五段・ラ行,連用タ接続,やる
1191 動詞,非自立,*,*,五段・ラ行,連用タ接続,回る
1192 動詞,非自立,*,*,五段・ラ行,連用タ接続,参る
1193 動詞,非自立,*,*,五段・ラ行,連用タ接続,終わる
1194 動詞,非自立,*,*,五段・ラ行,連用タ接続,切る
1195 動詞,非自立,*,*,五段・ラ行,連用形,*
1196 動詞,非自立,*,*,五段・ラ行,連用形,ある
1197 動詞,非自立,*,*,五段・ラ行,連用形,おる
1198 動詞,非自立,*,*,五段・ラ行,連用形,かかる
1199 動詞,非自立,*,*,五段・ラ行,連用形,きる
1200 動詞,非自立,*,*,五段・ラ行,連用形,なる
1201 動詞,非自立,*,*,五段・ラ行,連用形,まいる
1202 動詞,非自立,*,*,五段・ラ行,連用形,まわる
1203 動詞,非自立,*,*,五段・ラ行,連用形,やる
1204 動詞,非自立,*,*,五段・ラ行,連用形,回る
1205 動詞,非自立,*,*,五段・ラ行,連用形,参る
1206 動詞,非自立,*,*,五段・ラ行,連用形,終わる
1207 動詞,非自立,*,*,五段・ラ行,連用形,切る
1208 動詞,非自立,*,*,五段・ラ行特殊,仮定形,いらっしゃる
1209 動詞,非自立,*,*,五段・ラ行特殊,仮定形,なさる
1210 動詞,非自立,*,*,五段・ラ行特殊,仮定形,らっしゃる
1211 動詞,非自立,*,*,五段・ラ行特殊,仮定形,下さる
1212 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,いらっしゃる
1213 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,なさる
1214 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,らっしゃる
1215 動詞,非自立,*,*,五段・ラ行特殊,仮定縮約１,下さる
1216 動詞,非自立,*,*,五段・ラ行特殊,基本形,いらっしゃる
1217 動詞,非自立,*,*,五段・ラ行特殊,基本形,なさる
1218 動詞,非自立,*,*,五段・ラ行特殊,基本形,らっしゃる
1219 動詞,非自立,*,*,五段・ラ行特殊,基本形,下さる
1220 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,いらっしゃる
1221 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,なさる
1222 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,らっしゃる
1223 動詞,非自立,*,*,五段・ラ行特殊,未然ウ接続,下さる
1224 動詞,非自立,*,*,五段・ラ行特殊,未然形,いらっしゃる
1225 動詞,非自立,*,*,五段・ラ行特殊,未然形,なさる
1226 動詞,非自立,*,*,五段・ラ行特殊,未然形,らっしゃる
1227 動詞,非自立,*,*,五段・ラ行特殊,未然形,下さる
1228 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,いらっしゃる
1229 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,なさる
1230 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,らっしゃる
1231 動詞,非自立,*,*,五段・ラ行特殊,未然特殊,下さる
1232 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,いらっしゃる
1233 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,なさる
1234 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,らっしゃる
1235 動詞,非自立,*,*,五段・ラ行特殊,命令ｅ,下さる
1236 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,いらっしゃる
1237 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,なさる
1238 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,らっしゃる
1239 動詞,非自立,*,*,五段・ラ行特殊,命令ｉ,下さる
1240 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,いらっしゃる
1241 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,なさる
1242 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,らっしゃる
1243 動詞,非自立,*,*,五段・ラ行特殊,連用タ接続,下さる
1244 動詞,非自立,*,*,五段・ラ行特殊,連用形,いらっしゃる
1245 動詞,非自立,*,*,五段・ラ行特殊,連用形,なさる
1246 動詞,非自立,*,*,五段・ラ行特殊,連用形,らっしゃる
1247 動詞,非自立,*,*,五段・ラ行特殊,連用形,下さる
1248 動詞,非自立,*,*,五段・ワ行促音便,仮定形,*
1249 動詞,非自立,*,*,五段・ワ行促音便,仮定形,しまう
1250 動詞,非自立,*,*,五段・ワ行促音便,仮定形,もらう
1251 動詞,非自立,*,*,五段・ワ行促音便,仮定形,合う
1252 動詞,非自立,*,*,五段・ワ行促音便,基本形,*
1253 動詞,非自立,*,*,五段・ワ行促音便,基本形,しまう
1254 動詞,非自立,*,*,五段・ワ行促音便,基本形,もらう
1255 動詞,非自立,*,*,五段・ワ行促音便,基本形,合う
1256 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,*
1257 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,しまう
1258 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,もらう
1259 動詞,非自立,*,*,五段・ワ行促音便,未然ウ接続,合う
1260 動詞,非自立,*,*,五段・ワ行促音便,未然形,*
1261 動詞,非自立,*,*,五段・ワ行促音便,未然形,しまう
1262 動詞,非自立,*,*,五段・ワ行促音便,未然形,もらう
1263 動詞,非自立,*,*,五段・ワ行促音便,未然形,合う
1264 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,*
1265 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,しまう
1266 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,もらう
1267 動詞,非自立,*,*,五段・ワ行促音便,命令ｅ,合う
1268 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,*
1269 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,しまう
1270 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,もらう
1271 動詞,非自立,*,*,五段・ワ行促音便,連用タ接続,合う
1272 動詞,非自立,*,*,五段・ワ行促音便,連用形,*
1273 動詞,非自立,*,*,五段・ワ行促音便,連用形,しまう
1274 動詞,非自立,*,*,五段・ワ行促音便,連用形,もらう
1275 動詞,非自立,*,*,五段・ワ行促音便,連用形,合う
1276 動詞,非自立,*,*,四段・ハ行,仮定形,*
1277 動詞,非自立,*,*,四段・ハ行,基本形,*
1278 動詞,非自立,*,*,四段・ハ行,未然形,*
1279 動詞,非自立,*,*,四段・ハ行,命令ｅ,*
1280 動詞,非自立,*,*,四段・ハ行,連用形,*
1281 副詞,一般,*,*,*,*,*
1282 副詞,助詞類接続,*,*,*,*,*
1283 名詞,サ変接続,*,*,*,*,*
1284 名詞,ナイ形容詞語幹,*,*,*,*,*
1285 名詞,一般,*,*,*,*,*
1286 名詞,引用文字列,*,*,*,*,*
1287 名詞,形容動詞語幹,*,*,*,*,*
1288 名詞,固有名詞,一般,*,*,*,*
1289 名詞,固有名詞,人名,一般,*,*,*
1290 名詞,固有名詞,人名,姓,*,*,*
1291 名詞,固有名詞,人名,名,*,*,*
1292 名詞,固有名詞,組織,*,*,*,*
1293 名詞,固有名詞,地域,一般,*,*,*
1294 名詞,固有名詞,地域,国,*,*,*
1295 名詞,数,*,*,*,*,*
1296 名詞,接続詞的,*,*,*,*,*
1297 名詞,接尾,サ変接続,*,*,*,*
1298 名詞,接尾,一般,*,*,*,*
1299 名詞,接尾,形容動詞語幹,*,*,*,*
1300 名詞,接尾,助数詞,*,*,*,*
1301 名詞,接尾,助動詞語幹,*,*,*,*
1302 名詞,接尾,人名,*,*,*,*
1303 名詞,接尾,地域,*,*,*,*
1304 名詞,接尾,特殊,*,*,*,*
1305 名詞,接尾,副詞可能,*,*,*,*
1306 名詞,代名詞,一般,*,*,*,*
1307 名詞,代名詞,縮約,*,*,*,*
1308 名詞,動詞非自立的,*,*,*,*,*
1309 名詞,特殊,助動詞語幹,*,*,*,*
1310 名詞,非自立,一般,*,*,*,*
1311 名詞,非自立,形容動詞語幹,*,*,*,*
1312 名詞,非自立,助動詞語幹,*,*,*,*
1313 名詞,非自立,副詞可能,*,*,*,*
1314 名詞,副詞可能,*,*,*,*,*
1315 連体詞,*,*,*,*,*,*
